@@ -138,6 +138,13 @@ class GalleryBlock(blocks.StructBlock):
         label = "Gallery"
 
 
+class GallerySliderBlock(GalleryBlock):
+
+    class Meta:
+        template = '%s/common/gallery_slider.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Gallery Slider"
+
+
 class PersonBlock(blocks.StructBlock):
     person = SnippetChooserBlock('cms.Person', required=True)
 
