@@ -2,17 +2,12 @@ from wagtail.core import blocks
 
 from webspace.cms import constants
 from webspace.cms.blocks.choice import AlignTextChoiceBlock
-from webspace.cms.blocks.common import ButtonBlock, EntryBlock
+from webspace.cms.blocks.common import ButtonsBlock, EntryBlock
 
 
 class ButtonsEntry(EntryBlock):
     align = AlignTextChoiceBlock(required=False)
-    buttons = blocks.StreamBlock(
-        [
-            ('button', ButtonBlock()),
-        ],
-        max_num=3
-    )
+    buttons = ButtonsBlock()
 
     def mock(self, btn_one=constants.BUTTON_SECONDARY_FULL, btn_two=constants.BUTTON_SECONDARY, align='left',
              *args, **kwargs):
