@@ -247,40 +247,42 @@ const BgSlide = {
     const io = new IntersectionObserver(entries => entries.forEach((item) => {
       const element = item.target;
       const slides = element.querySelectorAll('.bg-container-item');
-      if (item.isIntersecting) {
-        const isSlider = element.classList.contains('slider');
-        if (!isSlider) {
-          const fSlides = Array.from(slides);
-          fSlides.shift();
-          let currentSlide = -1;
-          let reverse = true;
-          window.setInterval(() => {
-            currentSlide = (currentSlide + 1) % (fSlides.length);
-            reverse = currentSlide === 0 ? !reverse : reverse;
-            const index = !reverse ? currentSlide : (fSlides.length - currentSlide - 1);
-            fSlides[index].style.backgroundImage = `url(${fSlides[index].dataset.src})`;
-            fSlides[index].classList.remove('fade-in');
-            fSlides[index].classList.remove('fade-out');
-            fSlides[index].classList.add(!reverse ? 'fade-in' : 'fade-out');
-          }, 3000);
-        } else {
-          let i = 0;
-          const left = element.querySelector('.left');
-          const right = element.querySelector('.right');
-          function resfresh() {
-            for (let i = 0; i < slides.length; i++) {
-              slides[i].style.backgroundImage = '';
+      if (slides.length > 1) {
+        if (item.isIntersecting) {
+          const isSlider = element.classList.contains('slider');
+          if (!isSlider) {
+            const fSlides = Array.from(slides);
+            fSlides.shift();
+            let currentSlide = -1;
+            let reverse = true;
+            window.setInterval(() => {
+              currentSlide = (currentSlide + 1) % (fSlides.length);
+              reverse = currentSlide === 0 ? !reverse : reverse;
+              const index = !reverse ? currentSlide : (fSlides.length - currentSlide - 1);
+              fSlides[index].style.backgroundImage = `url(${fSlides[index].dataset.src})`;
+              fSlides[index].classList.remove('fade-in');
+              fSlides[index].classList.remove('fade-out');
+              fSlides[index].classList.add(!reverse ? 'fade-in' : 'fade-out');
+            }, 3000);
+          } else {
+            let i = 0;
+            const left = element.querySelector('.left');
+            const right = element.querySelector('.right');
+            function resfresh() {
+              for (let i = 0; i < slides.length; i++) {
+                slides[i].style.backgroundImage = '';
+              }
+              slides[i].style.backgroundImage = `url(${slides[i].dataset.src})`;
             }
-            slides[i].style.backgroundImage = `url(${slides[i].dataset.src})`;
+            right.addEventListener('click', (e) => {
+              i = i >= slides.length - 1 ? 0 : i + 1;
+              resfresh();
+            });
+            left.addEventListener('click', (e) => {
+              i = i === 0 ? slides.length - 1 : i - 1;
+              resfresh();
+            });
           }
-          right.addEventListener('click', (e) => {
-            i = i >= slides.length - 1 ? 0 : i + 1;
-            resfresh();
-          });
-          left.addEventListener('click', (e) => {
-            i = i === 0 ? slides.length - 1 : i - 1;
-            resfresh();
-          });
         }
         io.unobserve(element);
       }
